@@ -725,7 +725,7 @@ ldif_import(EImport *ei, EImportTarget *target, EImportImporter *im)
 	fseek(file, 0, SEEK_SET);
 	gci->dn_contact_hash = g_hash_table_new(g_str_hash, g_str_equal);
 
-	e_book_open(gci->book, TRUE, NULL);
+	e_book_open(gci->book, FALSE, NULL);
 
 	gci->idle_id = g_idle_add(ldif_import_contacts, gci);
 }
