@@ -86,9 +86,11 @@ typedef struct
 {
 	ESourceList *source_list;
 	ESourceList *task_source_list;
+	ESourceList *memo_source_list;
 	
 	GSList *source_selection;
 	GSList *task_source_selection;
+	GSList *memo_source_selection;
 	
 	GnomeCalendar *calendar;
 
@@ -104,6 +106,8 @@ typedef struct
 	EUserCreatableItemsHandler *creatable_items_handler;
 
 	EActivityHandler *activity_handler;
+	
+	float	     vpane_pos;
 } CalendarComponentView;
 
 struct _CalendarComponentPrivate {
@@ -115,6 +119,7 @@ struct _CalendarComponentPrivate {
 
 	ESourceList *source_list;
 	ESourceList *task_source_list;
+	ESourceList *memo_source_list;
 
 	GList *views;
 
@@ -126,6 +131,23 @@ struct _CalendarComponentPrivate {
 /* FIXME This should be gnome cal likely */
 extern ECompEditorRegistry *comp_editor_registry;
 
+static void
+calcomp_vpane_realized (GtkWidget *vpane, CalendarComponentView *view)
+{
+	gtk_paned_set_position (GTK_PANED (vpane), (int)(view->vpane_pos*vpane->allocation.height));
+	
+}
+
+static gboolean
+calcomp_vpane_resized (GtkWidget *vpane, GdkEventButton *e, CalendarComponentView *view)
+{
+
+	view->vpane_pos = gtk_paned_get_position (GTK_PANED (vpane));
+	calendar_config_set_tag_vpane_pos (view->vpane_pos/(float)vpane->allocation.height);
+
+	return FALSE;
+}
+
 static void
 ensure_sources (CalendarComponent *component)
 {
@@ -213,11 +235,13 @@ ensure_sources (CalendarComponent *component)
 	}
 
 	if (!personal_source) {
+		char *primary_calendar = calendar_config_get_primary_calendar();
+
 		/* Create the default Person addressbook */
 		personal_source = e_source_new (_("Personal"), PERSONAL_RELATIVE_URI);
 		e_source_group_add_source (on_this_computer, personal_source, -1);
-
-		if (!calendar_config_get_primary_calendar () && !calendar_config_get_calendars_selected ()) {
+		
+		if (!primary_calendar && !calendar_config_get_calendars_selected ()) {
 			GSList selected;
 
 			calendar_config_set_primary_calendar (e_source_peek_uid (personal_source));
@@ -226,7 +250,8 @@ ensure_sources (CalendarComponent *component)
 			selected.next = NULL;
 			calendar_config_set_calendars_selected (&selected);
 		}
-		
+
+		g_free (primary_calendar);
 		e_source_set_color (personal_source, 0xBECEDD);
 	}
 
@@ -388,39 +413,52 @@ update_selection (CalendarComponentView *component_view)
 }
 
 static void
-update_task_selection (CalendarComponentView *component_view)
+update_task_memo_selection (CalendarComponentView *component_view, ECalSourceType type)
 {
-	GSList *uids_selected, *l;
+	GSList *uids_selected, *l, *source_selection;
+	ESourceList *source_list = NULL;
 
-	/* Get the selection in gconf */
-	uids_selected = calendar_config_get_tasks_selected ();
+	if (type == E_CAL_SOURCE_TYPE_TODO) {
+		/* Get the selection in gconf */
+		uids_selected = calendar_config_get_tasks_selected ();
+		source_list = component_view->task_source_list;
+		source_selection = component_view->task_source_selection;
+		
+	} else {
+		uids_selected = calendar_config_get_memos_selected ();
+		source_list = component_view->memo_source_list;
+		source_selection = component_view->memo_source_selection;
+	}
 
 	/* Remove any that aren't there any more */
-	for (l = component_view->task_source_selection; l; l = l->next) {
+	for (l = source_selection; l; l = l->next) {
 		char *uid = l->data;
 		ESource *source;
 
-		source = e_source_list_peek_source_by_uid (component_view->task_source_list, uid);
+		source = e_source_list_peek_source_by_uid (component_view->source_list, uid);
 		if (!source)
-			gnome_calendar_remove_source_by_uid (component_view->calendar, E_CAL_SOURCE_TYPE_TODO, uid);
+			gnome_calendar_remove_source_by_uid (component_view->calendar, type, uid);
 		else if (!is_in_uids (uids_selected, source))
-			gnome_calendar_remove_source (component_view->calendar, E_CAL_SOURCE_TYPE_TODO, source);
+			gnome_calendar_remove_source (component_view->calendar, type, source);
 		
 		g_free (uid);
 	}
-	g_slist_free (component_view->task_source_selection);
+	g_slist_free (source_selection);
 
 	/* Make sure the whole selection is there */
 	for (l = uids_selected; l; l = l->next) {
 		char *uid = l->data;
 		ESource *source;
 
-		source = e_source_list_peek_source_by_uid (component_view->task_source_list, uid);
-		if (source && !gnome_calendar_add_source (component_view->calendar, E_CAL_SOURCE_TYPE_TODO, source))
+		source = e_source_list_peek_source_by_uid (source_list, uid);
+		if (source && !gnome_calendar_add_source (component_view->calendar, type, source))
 			/* FIXME do something */;
 	}
 
-	component_view->task_source_selection = uids_selected;
+	if (type == E_CAL_SOURCE_TYPE_TODO)
+		component_view->task_source_selection = uids_selected;
+	else
+		component_view->memo_source_selection = uids_selected;
 }
 
 static void
@@ -446,20 +484,28 @@ update_primary_selection (CalendarComponentView *component_view)
 }
 
 static void
-update_primary_task_selection (CalendarComponentView *component_view)
+update_primary_task_memo_selection (CalendarComponentView *component_view, ECalSourceType type)
 {
 	ESource *source = NULL;
 	char *uid;
+	ESourceList *source_list = NULL;
+
+	if (type == E_CAL_SOURCE_TYPE_TODO) {
+		uid = calendar_config_get_primary_tasks ();
+		source_list = component_view->task_source_list;
+	} else {
+		uid = calendar_config_get_primary_memos ();
+		source_list = component_view->memo_source_list;
+	}
 
-	uid = calendar_config_get_primary_tasks ();
 	if (uid) {
-		source = e_source_list_peek_source_by_uid (component_view->task_source_list, uid);
+		source = e_source_list_peek_source_by_uid (source_list, uid);
 
 		g_free (uid);
 	}
 	
 	if (source)
-		gnome_calendar_set_default_source (component_view->calendar, E_CAL_SOURCE_TYPE_TODO, source);
+		gnome_calendar_set_default_source (component_view->calendar, type, source);
 }
 
 /* Callbacks.  */
@@ -730,14 +776,27 @@ config_primary_selection_changed_cb (GConfClient *client, guint id, GConfEntry *
 static void
 config_tasks_selection_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer data)
 {
-	update_task_selection (data);
+	update_task_memo_selection (data, E_CAL_SOURCE_TYPE_TODO);
 }
 
 
 static void
 config_primary_tasks_selection_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer data)
 {
-	update_primary_task_selection (data);
+	update_primary_task_memo_selection (data, E_CAL_SOURCE_TYPE_TODO);
+}
+
+static void
+config_memos_selection_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer data)
+{
+	update_task_memo_selection (data, E_CAL_SOURCE_TYPE_JOURNAL);
+}
+
+
+static void
+config_primary_memos_selection_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer data)
+{
+	update_primary_task_memo_selection (data, E_CAL_SOURCE_TYPE_JOURNAL);
 }
 
 /* Evolution::Component CORBA methods.  */
@@ -1248,7 +1307,7 @@ create_component_view (CalendarComponent *calendar_component)
 {
 	CalendarComponentPrivate *priv;
 	CalendarComponentView *component_view;
-	GtkWidget *selector_scrolled_window, *vbox;
+	GtkWidget *selector_scrolled_window, *vbox, *vpane;
 	GtkWidget *statusbar_widget;
 	guint not;
 	AtkObject *a11y;
@@ -1258,9 +1317,17 @@ create_component_view (CalendarComponent *calendar_component)
 	/* Create the calendar component view */
 	component_view = g_new0 (CalendarComponentView, 1);
 	
+	vpane = gtk_vpaned_new ();
+	g_signal_connect_after (vpane, "realize",
+				G_CALLBACK(calcomp_vpane_realized), component_view);
+	g_signal_connect (vpane, "button_release_event",
+			  G_CALLBACK (calcomp_vpane_resized), component_view);
+	gtk_widget_show (vpane);
 	/* Add the source lists */
 	component_view->source_list = g_object_ref (priv->source_list);
 	component_view->task_source_list = g_object_ref (priv->task_source_list);
+	component_view->memo_source_list = g_object_ref (priv->memo_source_list);
+	component_view->vpane_pos = calendar_config_get_tag_vpane_pos ();
 	
 	/* Create sidebar selector */
 	component_view->source_selector = e_source_selector_new (calendar_component->priv->source_list);
@@ -1298,8 +1365,10 @@ create_component_view (CalendarComponent *calendar_component)
 	gtk_box_pack_start(GTK_BOX (vbox), GTK_WIDGET (component_view->info_label), FALSE, TRUE, 0);
 	gtk_box_pack_start(GTK_BOX (vbox), selector_scrolled_window, TRUE, TRUE, 0);
 	gtk_widget_show (vbox);
-
-	component_view->sidebar_control = bonobo_control_new (vbox);
+	
+	gtk_paned_pack1 (GTK_PANED (vpane), vbox, FALSE, TRUE);	
+	
+	component_view->sidebar_control = bonobo_control_new (vpane);
 
 	/* Create main view */
 	component_view->view_control = control_factory_new_control ();
@@ -1308,9 +1377,11 @@ create_component_view (CalendarComponent *calendar_component)
 
 		return NULL;
 	}
-
+	
 	component_view->calendar = (GnomeCalendar *) bonobo_control_get_widget (component_view->view_control);
 
+	gtk_paned_pack2 (GTK_PANED (vpane), gnome_calendar_get_tag (component_view->calendar), FALSE, TRUE);	
+
 	/* This signal is thrown if backends die - we update the selector */
 	g_signal_connect (component_view->calendar, "source_added", 
 			  G_CALLBACK (source_added_cb), component_view);
@@ -1348,18 +1419,28 @@ create_component_view (CalendarComponent *calendar_component)
 	/* Load the selection from the last run */
 	update_selection (component_view);	
 	update_primary_selection (component_view);
-	update_task_selection (component_view);
-	update_primary_task_selection (component_view);
+	update_task_memo_selection (component_view, E_CAL_SOURCE_TYPE_TODO);
+	update_primary_task_memo_selection (component_view, E_CAL_SOURCE_TYPE_TODO);
+	update_task_memo_selection (component_view, E_CAL_SOURCE_TYPE_JOURNAL);
+	update_primary_task_memo_selection (component_view, E_CAL_SOURCE_TYPE_JOURNAL);
 
-	/* If the tasks selection changes elsewhere, update it for the mini
+	/* If the tasks/memos selection changes elsewhere, update it for the mini
 	   mini tasks view sidebar */
 	not = calendar_config_add_notification_tasks_selected (config_tasks_selection_changed_cb, 
 							       component_view);
 	component_view->notifications = g_list_prepend (component_view->notifications, GUINT_TO_POINTER (not));
 
+	not = calendar_config_add_notification_memos_selected (config_memos_selection_changed_cb, 
+							       component_view);
+	component_view->notifications = g_list_prepend (component_view->notifications, GUINT_TO_POINTER (not));
+
 	not = calendar_config_add_notification_primary_tasks (config_primary_tasks_selection_changed_cb, 
 							      component_view);
 	component_view->notifications = g_list_prepend (component_view->notifications, GUINT_TO_POINTER (not));
+	
+	not = calendar_config_add_notification_primary_memos (config_primary_memos_selection_changed_cb, 
+							      component_view);
+	component_view->notifications = g_list_prepend (component_view->notifications, GUINT_TO_POINTER (not));
 
 	return component_view;
 }
@@ -1374,6 +1455,9 @@ destroy_component_view (CalendarComponentView *component_view)
 
 	if (component_view->task_source_list)
 		g_object_unref (component_view->task_source_list);
+	
+	if (component_view->memo_source_list)
+		g_object_unref (component_view->memo_source_list);
 
 	if (component_view->source_selection)
 		e_source_selector_free_selection (component_view->source_selection);
@@ -1616,8 +1700,11 @@ calendar_component_init (CalendarComponent *component)
 
 	component->priv = priv;
 	ensure_sources (component);
+
 	if (!e_cal_get_sources (&priv->task_source_list, E_CAL_SOURCE_TYPE_TODO, NULL))
 		;
+	if (!e_cal_get_sources (&priv->memo_source_list, E_CAL_SOURCE_TYPE_JOURNAL, NULL))
+		;
 }
 
 
