@@ -297,7 +297,7 @@ generate_viewoption_menu (GtkWidget *emfv)
 	for (i = 0; emfb_view_items[i].search.id != -1; ++i) {
 		if (emfb_view_items[i].search.text) {
 			char *str;
-			str = string_without_underscores (emfb_view_items[i].search.text);
+			str = string_without_underscores (_(emfb_view_items[i].search.text));
 			menu_item = gtk_image_menu_item_new_with_label (str);
 /* 			if (emfb_view_items[i].image)
  				gtk_image_menu_item_set_image (menu_item, e_icon_factory_get_image (emfb_view_items[i].image, E_ICON_SIZE_MENU)); */
@@ -352,7 +352,7 @@ generate_viewoption_menu (GtkWidget *emfv)
 	for (i = 0; temp_view_items[i].search.id != -1; ++i) {
 		if (temp_view_items[i].search.text) {
 			char *str;
-			str = string_without_underscores (temp_view_items[i].search.text);
+			str = string_without_underscores (_(temp_view_items[i].search.text));
 			menu_item = gtk_image_menu_item_new_with_label (str);
 /*			if (temp_view_items[i].image)
 				gtk_image_menu_item_set_image (menu_item, e_icon_factory_get_image (temp_view_items[i].image, E_ICON_SIZE_MENU)); */
@@ -645,7 +645,6 @@ void em_folder_browser_show_preview(EMFolderBrowser *emfb, gboolean state)
 		gtk_widget_hide(emfb->priv->preview);
 		e_search_bar_scope_enable ((ESearchBar *)emfb->search, E_FILTERBAR_CURRENT_MESSAGE_ID, FALSE);		
 		emfb->priv->scope_restricted = TRUE;
-		printf("%s(%d):%s: TRUE\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 		/*
 		mail_display_set_message (emfb->mail_display, NULL, NULL, NULL);
 		emfb_ui_message_loaded (emfb);*/
