@@ -52,6 +52,7 @@
 #include <gtk/gtklabel.h>
 #include <gtk/gtkentry.h>
 #include <gtk/gtkscrolledwindow.h>
+#include <gtk/gtktextview.h>
 #include <gtk/gtktogglebutton.h>
 #include <gtk/gtktable.h>
 #include <gtk/gtkmenu.h>
@@ -60,6 +61,7 @@
 #include <gtk/gtkdnd.h>
 #include <gtk/gtktoolbutton.h>
 #include <gtk/gtkframe.h>
+#include <gtk/gtkcheckbutton.h>
 
 #include <glade/glade.h>
 
@@ -641,13 +643,14 @@ em_format_html_get_search_dialog (EMFormatHTMLDisplay *efhd)
 
 	p->search_entry_box = gtk_hbox_new (FALSE, 0);
 
-	label1 = gtk_label_new (_("Find:"));
+	label1 = gtk_label_new_with_mnemonic (_("Fi_nd:"));
 	gtk_widget_show (label1);
 	gtk_box_pack_start ((GtkBox *)(p->search_entry_box), label1, FALSE, FALSE, 5);
 
 	/* Icon entry */
 	icon_entry = e_icon_entry_new ();
 	p->search_entry = e_icon_entry_get_entry (E_ICON_ENTRY (icon_entry));
+	gtk_label_set_mnemonic_widget (label1, p->search_entry);
 	gtk_widget_show (p->search_entry);
 	clear_button = e_icon_entry_create_button ("gtk-clear");
 	e_icon_entry_pack_widget (E_ICON_ENTRY (icon_entry), clear_button, FALSE);
@@ -668,7 +671,8 @@ em_format_html_get_search_dialog (EMFormatHTMLDisplay *efhd)
 	gtk_widget_show (button3);
 	gtk_box_pack_start ((GtkBox *)(hbox2), button3, FALSE, FALSE, 5);
 
-	button2 = gtk_button_new_from_stock ("gtk-go-forward");
+	button2 = gtk_button_new_with_mnemonic (_("Fo_rward"));
+	gtk_button_set_image (button2, gtk_image_new_from_stock(GTK_STOCK_GO_FORWARD, GTK_ICON_SIZE_BUTTON));
 	gtk_widget_show (button2);
 	gtk_box_pack_start ((GtkBox *)(hbox2), button2, FALSE, FALSE, 5);
 
@@ -743,7 +747,6 @@ void
 em_format_html_display_search_with (EMFormatHTMLDisplay *efhd, char *word)
 {
 	struct _EMFormatHTMLDisplayPrivate *p = efhd->priv;
-	char *str;
 
 	if (p->search_dialog){
                GtkWidget *toplevel;
@@ -1086,10 +1089,24 @@ efhd_xpkcs7mime_validity_clicked(GtkWidget *button, EMFormatHTMLPObject *pobject
 	gtk_label_set_line_wrap((GtkLabel *)w, TRUE);
 	gtk_box_pack_start((GtkBox *)vbox, w, TRUE, TRUE, 6);
 	if (po->valid->sign.description) {
-		w = gtk_label_new(po->valid->sign.description);
-		gtk_misc_set_alignment((GtkMisc *)w, 0.0, 0.5);
-		gtk_label_set_line_wrap((GtkLabel *)w, FALSE);
-		gtk_label_set_selectable((GtkLabel *)w, TRUE);
+		GtkTextBuffer *buffer;
+
+		buffer = gtk_text_buffer_new(NULL);
+		gtk_text_buffer_set_text(buffer, po->valid->sign.description, strlen(po->valid->sign.description));
+		w = g_object_new(gtk_scrolled_window_get_type(),
+				 "hscrollbar_policy", GTK_POLICY_AUTOMATIC,
+				 "vscrollbar_policy", GTK_POLICY_AUTOMATIC,
+				 "shadow_type", GTK_SHADOW_IN,
+				 "child", g_object_new(gtk_text_view_get_type(),
+						       "buffer", buffer,
+						       "cursor_visible", FALSE,
+						       "editable", FALSE,
+						       "width_request", 500,
+						       "height_request", 160,
+						       NULL),
+				 NULL);
+		g_object_unref(buffer);
+
 		gtk_box_pack_start((GtkBox *)vbox, w, TRUE, TRUE, 6);
 	}
 
@@ -1104,10 +1121,24 @@ efhd_xpkcs7mime_validity_clicked(GtkWidget *button, EMFormatHTMLPObject *pobject
 	gtk_label_set_line_wrap((GtkLabel *)w, TRUE);
 	gtk_box_pack_start((GtkBox *)vbox, w, TRUE, TRUE, 6);
 	if (po->valid->encrypt.description) {
-		w = gtk_label_new(po->valid->encrypt.description);
-		gtk_misc_set_alignment((GtkMisc *)w, 0.0, 0.5);
-		gtk_label_set_line_wrap((GtkLabel *)w, FALSE);
-		gtk_label_set_selectable((GtkLabel *)w, TRUE);
+		GtkTextBuffer *buffer;
+
+		buffer = gtk_text_buffer_new(NULL);
+		gtk_text_buffer_set_text(buffer, po->valid->encrypt.description, strlen(po->valid->encrypt.description));
+		w = g_object_new(gtk_scrolled_window_get_type(),
+				 "hscrollbar_policy", GTK_POLICY_AUTOMATIC,
+				 "vscrollbar_policy", GTK_POLICY_AUTOMATIC,
+				 "shadow_type", GTK_SHADOW_IN,
+				 "child", g_object_new(gtk_text_view_get_type(),
+						       "buffer", buffer,
+						       "cursor_visible", FALSE,
+						       "editable", FALSE,
+						       "width_request", 500,
+						       "height_request", 160,
+						       NULL),
+				 NULL);
+		g_object_unref(buffer);
+
 		gtk_box_pack_start((GtkBox *)vbox, w, TRUE, TRUE, 6);
 	}
 
@@ -1535,7 +1566,7 @@ efhd_drag_data_get(GtkWidget *w, GdkDragContext *drag, GtkSelectionData *data, g
 			return;
 		}
 
-		path = em_utils_temp_save_part(w, part);
+		path = em_utils_temp_save_part(w, part, FALSE);
 		if (path == NULL)
 			return;
 
@@ -2153,7 +2184,7 @@ efhd_attachment_bar_refresh (EMFormatHTMLDisplay *efhd)
 		char *txt;
 
 		/* Cant i put in the number of attachments here ?*/
-		txt = g_strdup_printf(ngettext("%d attachme_nt", "%d attachme_nts", nattachments), nattachments);
+		txt = g_strdup_printf(ngettext("%d at_tachment", "%d at_tachments", nattachments), nattachments);
 		gtk_label_set_text_with_mnemonic ((GtkLabel *)efhd->priv->label, txt);
 		g_free (txt);
 	
@@ -2185,8 +2216,10 @@ efhd_bar_resize(GtkWidget *w, GtkAllocation *event, EMFormatHTML *efh)
 
 	gtk_widget_size_request (efhd->priv->attachment_bar, &req);
 	width = ((GtkWidget *) efh->html)->allocation.width - 16;
-	/* Update the width of the bar */
-	e_attachment_bar_set_width(E_ATTACHMENT_BAR(efhd->priv->attachment_bar), width);
+	
+	/* Update the width of the bar when the width is greater than 1*/
+	if (width > 0)
+		e_attachment_bar_set_width(E_ATTACHMENT_BAR(efhd->priv->attachment_bar), width);
 }
 
 static gboolean
@@ -2216,7 +2249,7 @@ efhd_add_bar(EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObject *pobjec
 	EMFormatHTMLDisplay *efhd = (EMFormatHTMLDisplay *)efh;
 	struct _EMFormatHTMLDisplayPrivate *priv = efhd->priv;
 	GtkWidget *hbox1, *hbox2, *hbox3, *vbox, *txt, *image, *save, *scroll;
-	int width, height;
+	int width, height, bar_width;
 
 	priv->attachment_bar = e_attachment_bar_new(NULL);
 	scroll = gtk_scrolled_window_new (NULL, NULL);
@@ -2257,9 +2290,10 @@ efhd_add_bar(EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObject *pobjec
 
 	/* FIXME: What if the text is more?. Should we reduce the text with appending ...?
 	 * or resize the bar? How to figure out that, it needs more space? */
+	bar_width = ((GtkWidget *)efh->html)->parent->allocation.width - /* FIXME */16;
 	gtk_widget_set_size_request (priv->attachment_bar, 
-					((GtkWidget *)efh->html)->parent->allocation.width - /* FIXME */16,
-					84 /* FIXME: Default show only one row, Dont hardcode size*/);
+				     bar_width > 0 ? bar_width : 0,
+				     84 /* FIXME: Default show only one row, Dont hardcode size*/);
 	
 	vbox = gtk_vbox_new (FALSE, 0);
 	gtk_box_pack_start ((GtkBox *)vbox, hbox2, FALSE, FALSE, 2);
