@@ -37,6 +37,7 @@
 #include <gtk/gtklabel.h>
 #include <gtk/gtkimage.h>
 #include <gtk/gtkbox.h>
+#include <gtk/gtkscrolledwindow.h>
 #include <libgnomeui/gnome-window-icon.h>
 #include <libgnome/gnome-i18n.h>
 
@@ -285,13 +286,17 @@ format_url(const char *internal_url, const char *account_name)
 static send_info_t get_receive_type(const char *url)
 {
 	CamelProvider *provider;
+	CamelException ex;
 
 	/* HACK: since mbox is ALSO used for native evolution trees now, we need to
 	   fudge this to treat it as a special 'movemail' source */
 	if (!strncmp(url, "mbox:", 5))
 		return SEND_RECEIVE;
 
-	provider = camel_provider_get(url, NULL);
+	camel_exception_init (&ex);
+	provider = camel_provider_get(url, &ex);
+	camel_exception_clear (&ex);
+
 	if (!provider)
 		return SEND_INVALID;
 	
@@ -307,6 +312,21 @@ static send_info_t get_receive_type(const char *url)
 	return SEND_INVALID;
 }
 
+gboolean
+dialog_map (GtkWidget *window, GdkEvent  *event, GtkWidget *table)
+{
+	int h, w;
+
+	w = table->allocation.width + 30 /* Spacing around the table */;
+	h = table->allocation.height + 60 /* Cancell All button and Seperator and outer spacing */;
+
+	if (w > 750)
+		w = 750;
+	if (h > 400)
+		h = 400;
+	gtk_widget_set_usize (window, w, h);
+}
+
 static struct _send_data *
 build_dialog (EAccountList *accounts, CamelFolder *outbox, const char *destination)
 {
@@ -315,7 +335,7 @@ build_dialog (EAccountList *accounts, CamelFolder *outbox, const char *destinati
 	int row, num_sources;
 	GList *list = NULL;
 	struct _send_data *data;
-        GtkWidget *send_icon, *recv_icon; 
+        GtkWidget *send_icon, *recv_icon,*scrolled_window; 
 	GtkLabel *label;
 	EClippedLabel *status_label;
 	GtkProgressBar *bar;
@@ -331,7 +351,7 @@ build_dialog (EAccountList *accounts, CamelFolder *outbox, const char *destinati
 	
 	gtk_widget_ensure_style ((GtkWidget *)gd);
 	gtk_container_set_border_width ((GtkContainer *)gd->vbox, 0);
-	gtk_container_set_border_width ((GtkContainer *)gd->action_area, 12);
+	gtk_container_set_border_width ((GtkContainer *)gd->action_area, 6);
 
 	stop = (GtkButton *)e_gtk_button_new_with_icon(_("Cancel _All"), GTK_STOCK_CANCEL);
 	gtk_widget_show((GtkWidget *)stop);
@@ -359,12 +379,20 @@ build_dialog (EAccountList *accounts, CamelFolder *outbox, const char *destinati
 	g_object_unref (iter);
 	
 	table = (GtkTable *) gtk_table_new (num_sources, 4, FALSE);
-	gtk_container_set_border_width ((GtkContainer *) table, 12);
+	gtk_container_set_border_width ((GtkContainer *) table, 6);
 	gtk_table_set_row_spacings (table, 6);
 	gtk_table_set_col_spacings (table, 6);
 
-       	gtk_box_pack_start (GTK_BOX (gd->vbox), GTK_WIDGET (table), TRUE, TRUE, 0);
-	
+	scrolled_window = gtk_scrolled_window_new (NULL, NULL);	
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
+					GTK_POLICY_AUTOMATIC,
+					GTK_POLICY_AUTOMATIC);
+
+	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (scrolled_window), table);
+	gtk_box_pack_start (GTK_BOX (gd->vbox), scrolled_window,TRUE, TRUE, 0); 
+	gtk_widget_set_usize (gd->vbox, 600,200);
+	gtk_widget_show (GTK_WIDGET (scrolled_window));	
+
 	/* must bet setup after send_recv_dialog as it may re-trigger send-recv button */
 	data = setup_send_data ();
 	
@@ -498,6 +526,7 @@ build_dialog (EAccountList *accounts, CamelFolder *outbox, const char *destinati
 	gtk_widget_show (GTK_WIDGET (gd));
 	
 	g_signal_connect (gd, "response", G_CALLBACK (dialog_response), data);
+	g_signal_connect (gd, "map-event", G_CALLBACK (dialog_map), table);
 	
 	g_object_weak_ref ((GObject *) gd, (GWeakNotify) dialog_destroy_cb, data);
 	
