@@ -52,6 +52,7 @@ typedef enum {
 	E_CHARSET_HEBREW,
 	E_CHARSET_JAPANESE,
 	E_CHARSET_KOREAN,
+	E_CHARSET_THAI,
 	E_CHARSET_TURKISH,
 	E_CHARSET_UNICODE,
 	E_CHARSET_WESTERN_EUROPEAN,
@@ -68,6 +69,7 @@ static const char *classnames[] = {
 	N_("Hebrew"),
 	N_("Japanese"),
 	N_("Korean"),
+	N_("Thai"),
 	N_("Turkish"),
 	N_("Unicode"),
 	N_("Western European"),
@@ -105,6 +107,7 @@ static ECharset charsets[] = {
 	{ "EUC-JP", E_CHARSET_JAPANESE, NULL },
 	{ "Shift_JIS", E_CHARSET_JAPANESE, NULL },
 	{ "EUC-KR", E_CHARSET_KOREAN, NULL },
+	{ "TIS-620", E_CHARSET_THAI, NULL },
 	{ "ISO-8859-9", E_CHARSET_TURKISH, NULL },
 	{ "UTF-8", E_CHARSET_UNICODE, NULL },
 	{ "UTF-7", E_CHARSET_UNICODE, NULL },
